function out = BCO_objective_steadyerosion_simple(X,d,p,dFlag)

% This is the objective function for fitting exercise 3.
%
% out = BCO_objective_steadyerosion_simple(X,d,p,dFlag)
% 
% where X has the following params:
%   X(1) erosion rate (m/Myr)
%   X(2) Ne closure age (Myr)
%   X(3) N21sp0 (10^8 atoms) 
%
% d is data structure with core data
% p is additional struct with things like surface production rate, etc. 
% dflag is 0 for objective fctn; 1 for diagnostic struct
%
% Greg Balco - Berkeley Geochronology Center - 2018
% Not licensed for reuse or distribution

% Get in correct dimensions

ee = X(1).*p.rho.*1e-4; % to g/cm2/yr
tc = X(2).*1e6; % to Ma
N21sp0 = X(3).*1e8;

% Nucleogenic

% Alpha production
d.a232perg = 6.*d.atsThperg.*(exp(p.l232.*tc) - 1);
d.a235perg = 7.*d.ats235perg.*(exp(p.l235.*tc) - 1);
d.a238perg = 8.*d.ats238perg.*(exp(p.l238.*tc) - 1);

% Ne-21 production
r.N21nuc = d.Ft.*( d.a232perg.*6.08e-8 + d.a235perg.*5.62e-8 + d.a238perg.*4.04e-8 );
r.delN21nuc = r.N21nuc.*p.dnfactor;

% Spallogenic

r.N21sp = N21sp0.*exp(-d.z./p.Lsp);

% Muons

for a = 1:length(d.N21m);
	r.N21mu(a) = integral(@(t) interp1(log(p.predz),p.Pmu,log(d.z(a)+ee.*t)),0,p.texp,'reltol',1e-3,'abstol',1e-2);
end;

% Total

r.N21p = r.N21nuc + r.N21sp + r.N21mu';
r.delN21p = r.delN21nuc;
r.miss = ((r.N21p - d.N21m)./sqrt((d.delN21m.*p.dmfactor).^2 + r.delN21p.^2));
r.missquared = r.miss.^2;
r.x2 = sum(r.missquared);

if dFlag == 0;
    out = r.x2;
elseif dFlag == 1;
    out = r;
end;

