% This script obtains Ne closure ages for Mackay Glacier samples. Just
% solves Equation 3 in paper for tC. 
%
% Greg Balco - Berkeley Geochronology Center - 2018
% Not licensed for reuse or distribution

clear all; close all;

% Enter data. These are from Table 2 in paper. 

N21 = [7.60
2.70
5.61
10.11
7.84
9.17
7.04
7.93
5.84
8.12
4.50
8.91
6.81];

dN21 = [1.3
1.0
1.8
1.8
1.2
1.6
0.8
1.0
1.5
1.0
1.1
1.0
1.1];

U = [0.085
0.051
0.100
0.139
0.115
0.175
0.210
0.137
0.094
0.184
0.100
0.153
0.162];

Th = [0.344
0.201
0.286
0.205
0.238
0.198
0.505
0.345
0.221
0.458
0.186
0.201
0.330];


for a = 1:length(N21);
    thisN21 = N21(a).*1e6;
    thisU = U(a);
    thisTh = Th(a);
    thist(a) = fzero(@(x) (thisN21 - objective_Ne_closure(x,thisU,thisTh)),177);
end;
    
% Uncertainty estimate. Linearize, assume 20% uncert on alpha production. 
thist = thist';
thisdelt = sqrt ( (thist.*0.25).^2 + (thist.*dN21./N21).^2);


disp(sprintf('%0.0f %0.0f\n',[thist thisdelt]'/1e6));

