% This makes Figure 4 (albedo effect demonstration). 
%
% 
% Greg Balco - Berkeley Geochronology Center - June 2018


clear all; close all;

% get data

d = create_BCO_data();

np = length(d.N21m);
slab = 'v^';
 
figure;
ax1 = axes('pos',[0.2 0.11 0.7 0.8150]);

for a = 1:np;
    xx = [d.N21m(a)-d.delN21m(a) d.N21m(a)+d.delN21m(a)];
    yy = [d.z(a) d.z(a)];
    plot(xx,yy,'k'); hold on;
end;

for a = 1:np;
    if d.source(a) == 1; 
        cc = [0 0 0]; 
    elseif d.source(a) == 2;
        cc = [1 1 1];
    elseif d.source(a) == 3;
        cc = [0.5 0.5 0.5];
    end;    
    plot(d.N21m(a),d.z(a),['k' slab(d.lab(a))],'markerfacecolor',cc);
end;

% exponential fitting

ok = find((d.z < 300) & (d.z > 30) & (d.lab == 1));

fitx = d.z(ok); fity = log(d.N21m(ok));

p1 = polyfit(fitx,fity,1);

pz = 0:150;
%px = exp(polyval(p1,pz));
%plot(px,pz,'r');

plot(exp(log(5.55e8)-pz./140),pz,'r')

set(gca,'ydir','reverse','ylim',[0 50]);
set(gca,'xlim',[3e8 7e8]);
set(gca,'xscale','log');
grid on;
ylabel('Mass depth (g cm^{-2})');
xlabel('Excess ^{21}Ne (atoms g^{-1})');
set(gca,'fontsize',12);

% Second axis in depth
ax2 = axes('pos',[0.1 0.11 0.01 0.8150]);

rho = 73.5./31.5;
maxy = 50./rho;
set(ax2,'xtick',[]);
set(ax2,'ylim',[0 maxy],'ydir','reverse');
ylabel('Depth (cm)');
set(gca,'fontsize',12);
